@@ -488,11 +488,12 @@ CollapseEdge <- function(tree, edges) {
 #'
 #' `MakeTreeBinary()` resolves, at random, all polytomies in a tree or set of
 #' trees, such that all trees compatible with the input topology are drawn
-#' with equal probability.
+#' with equal probability. Edge lengths are not yet supported, so are removed.
 #'
 #' @seealso Since ape v5.5, this functionality is available through
 #' [`ape::multi2di()`]; previous versions of "ape" did not return topologies
-#' in equal frequencies.
+#' in equal frequencies.  `MakeTreeBinary()` is often somewhat faster;
+#' `multi2di()` retains edge lengths.
 #'
 #' @return `MakeTreeBinary()` returns a rooted binary tree of class `phylo`,
 #' corresponding to tree uniformly selected from all those compatible with
@@ -511,19 +512,21 @@ MakeTreeBinary <- function(tree) {
 
 #' @export
 MakeTreeBinary.phylo <- function(tree) {
-  tree <- Preorder(tree)
+  tree <- Preorder(`[[<-`(tree, "edge.length", NULL))
   degree <- NodeOrder(tree, internalOnly = TRUE)
-  degree[1] <- degree[1] + 1L # Root node
+  degree[[1]] <- degree[[1]] + 1L # Root node is degree 2
   polytomies <- degree > 3L
-  if (!any(polytomies)) return(tree)
+  if (!any(polytomies)) {
+    return(tree)
+  }
   edge <- tree[["edge"]]
 
-  nTip <- edge[1] - 1L
+  nTip <- edge[[1]] - 1L
   polytomyN <- which(polytomies) + nTip
   degree <- degree[polytomies]
   for (i in seq_len(sum(polytomies))) {
-    n <- polytomyN[i]
-    nKids <- degree[i] - 1L
+    n <- polytomyN[[i]]
+    nKids <- degree[[i]] - 1L
     newParent <- .RandomParent(nKids + 1L) # Tip 1 is the "root"
     newEdges <- RenumberEdges(newParent, seq_len(nKids + nKids))
 
@@ -553,7 +556,7 @@ MakeTreeBinary.phylo <- function(tree) {
   nodeLabel <- tree[["node.label"]]
   if (!is.null(nodeLabel)) {
     # Inefficient but pragmatic
-    tree[["node.label"]] <- .UpdateNodeLabel.numeric(edge, tree,  nodeLabel)
+    tree[["node.label"]] <- .UpdateNodeLabel.numeric(edge, tree, nodeLabel)
   }
   tree[["edge"]] <- edge
   tree[["Nnode"]] <- nTip - 1L
